==> apache-superset-incubating-0.36.0-source.tar.gz: apache-superset-incubating-0.36.0rc3/tests/tagging_tests.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from unittest import skipUnless

from superset import is_feature_enabled
from tests.base_tests import SupersetTestCase


class TaggingTests(SupersetTestCase):
    @skipUnless(
        (is_feature_enabled("TAGGING_SYSTEM") == False),
        "skipping as tagging endpoints are not enabled",
    )
    def test_tag_view_attachment_disabled(self):
        response = self.client.get("/tagview/tagged_objects/")
        self.assertEqual(404, response.status_code)

    @skipUnless(
        is_feature_enabled("TAGGING_SYSTEM"),
        "skipping as tagging endpoints are enabled",
    )
    def test_tag_view_attachment_enabled(self):
        response = self.client.get("/tagview/tagged_objects/")
        self.assertEqual(200, response.status_code)

==> apache-superset-incubating-0.38.0rc1-source.tar.gz: apache-superset-incubating-0.38.0rc1/tests/tagging_tests.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from unittest import skipUnless

from superset import is_feature_enabled
from tests.base_tests import SupersetTestCase


class TestTagging(SupersetTestCase):
    @skipUnless(
        (is_feature_enabled("TAGGING_SYSTEM") == False),
        "skipping as tagging endpoints are not enabled",
    )
    def test_tag_view_attachment_disabled(self):
        response = self.client.get("/tagview/tagged_objects/")
        self.assertEqual(404, response.status_code)

    @skipUnless(
        is_feature_enabled("TAGGING_SYSTEM"),
        "skipping as tagging endpoints are enabled",
    )
    def test_tag_view_attachment_enabled(self):
        response = self.client.get("/tagview/tagged_objects/")
        self.assertEqual(200, response.status_code)
